@@ -1014,6 +1014,16 @@ class StringFilterTestCase(unittest.TestCase):
                 kwargs={},
                 expect="Have you read Ulysses &amp; &#20;?",
             ),
+            Case(
+                description="some HTML markup with HTML comment",
+                val=(
+                    "<!-- Have --><em>you</em> read "
+                    "<strong>Ulysses</strong> &amp; &#20;?"
+                ),
+                args=[],
+                kwargs={},
+                expect="you read Ulysses &amp; &#20;?",
+            ),
             Case(
                 description="not a string",
                 val=5,
@@ -1262,6 +1272,13 @@ class StringFilterTestCase(unittest.TestCase):
                 kwargs={},
                 expect="one two",
             ),
+            Case(
+                description="very long argument",
+                val="",
+                args=[100000000000000],
+                kwargs={},
+                expect="",
+            ),
         ]
 
         self._test(TruncateWords, test_cases)
